<!--执勤统计分析-->
<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form ref="queryRef" v-model="query" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="姓名">
              <el-input v-model="query.name" :clearable="true" placeholder="请输入姓名" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="行为类型">
              <el-select v-model="query.warnType" clearable filterable placeholder="请选择行为类型" size="small"
                         style="width:100%">
                <el-option v-for="item in warningTypeOpt" :key="item.value" :label="item.name" :value="item.value">
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="行为时间">
              <el-date-picker v-model="query.warnTime" :clearable="true" format="yyyy-MM-dd"
                              placeholder="请选择行为时间"
                              size="small"
                              type="date" value-format="yyyy-MM-dd" />
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button icon="el-icon-search" type="primary" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div ref="contentPanel" class="bbsl-table-content">
      <el-table ref="multipleSelection" v-loading="loading" :border="true" :cell-style="{ 'text-align': 'center' }"
                :data="tableData"
                :header-cell-style="{ 'text-align': 'center' }" :max-height="tableMaxHeight" :style="{ width: '100%' }"
                size="mini" @row-dblclick="() => { }"
                @selection-change="handleSelectionChange">
        <el-table-column label="序号" type="index" width="60" />
        <!-- <el-table-column prop="number" label="编号" :show-overflow-tooltip="true" /> -->
        <el-table-column :show-overflow-tooltip="true" label="姓名" prop="name" />
        <el-table-column :show-overflow-tooltip="true" label="电话" prop="telePhone" />
        <el-table-column :show-overflow-tooltip="true" label="行为时间" prop="warnTime" />
        <el-table-column
          :formatter="({ warnType }) => warningTypeOpt.length && warningTypeOpt.find(i => i.value === warnType).name"
          :show-overflow-tooltip="true"
          label=" 行为类型"
          prop="warnType" />
        <el-table-column :show-overflow-tooltip="true" label="区域" prop="areaName" />
        <el-table-column :show-overflow-tooltip="true" label="执勤状态" prop="status">

          <template #default="{ row }">
            <el-tag v-if="row.status === '0'" type="success">正常</el-tag>
            <el-tag v-if="row.status === '1'" type="warning">异常</el-tag>
          </template>
        </el-table-column>
        <el-table-column label="操作" min-width="90" prop="" show-overflow-tooltip>
          <template #default="scope">
            <el-button size="small" type="primary" @click="handleEquipment(scope.row)">执勤报备</el-button>
          </template>
        </el-table-column>
        <!-- <el-table-column prop="latitude" label="经度" :show-overflow-tooltip="true" /> -->
        <!-- <el-table-column prop="longitude" label="纬度" :show-overflow-tooltip="true" /> -->
      </el-table>
      <el-pagination ref="paginationPanel" :background="true" :current-page="queryParam.pageBean.page"
                     :page-size="queryParam.pageBean.pageSize" :page-sizes="[20, 30, 40, 50]"
                     :total="total" class="bbsl-pagination"
                     layout="total, sizes, prev, pager, next, jumper"
                     @size-change="handleSizeChange" @current-change="handleCurrentChange" />
    </div>
    <ReportOnDutyDialog ref="formModal"></ReportOnDutyDialog>
  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import CMGTDutyAnalysisRelevancyApi from '@/api/CMGTDutyBehaviorAnalysisApi'
import dictUtils from '@/components/dict/DictSelectUtils'
import ReportOnDutyDialog from '@/views/Manage/duty/CMGTDutyBehaviorAnalysis/components/ReportOnDutyDialog.vue'

const {getTableData} = CMGTDutyAnalysisRelevancyApi

export default {
  name: 'CMGTDutyBehaviorAnalysis', // 执勤统计分析
  components: {ReportOnDutyDialog},
  mixins: [TableMixin],
  data() {
    return {
      // 表格产讯参数
      query: {
        warnTime: '',
        name: '',
        warnType: ''
      },
      dutyRecordsDialog: false,// 执勤电子档案弹层
      warningTypeOpt: [] // 行为类型下拉
    }
  },
  created() {
    this.warningTypeOpt = dictUtils.getDictItemsFromCache('qwrygjlx')
  },
  mounted() {
  },
  methods: {
    handleEquipment(row) {
      this.$refs.formModal.open(row)
    },
    // 重置
    clearQuerys() {
      this.query = this.$options.data().query
    },

    // 获取表格数据
    loadData(page) {
      this.loading = true
      if (page) this.queryParam.pageBean.page = page
      /*
      * this.queryParam 为封装的分页数组对象
      * this.query 为表格条件查询参数
      * */
      getTableData(this.query, this.queryParam, res => {
        const {total, rows: tableData} = res
        this.total = total
        this.tableData = tableData
        this.loading = false
      })
    }

  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
